fn advance_context_after_word(word: &str, ctx: GrammarContext) -> GrammarContextExpand description
Advance the grammar context after seeing a word token.
fn advance_context_after_word(word: &str, ctx: GrammarContext) -> GrammarContextAdvance the grammar context after seeing a word token.