fn is_strict_identifier_context(ctx: GrammarContext) -> boolExpand description
Contexts where the next word is always an identifier (a name), regardless of whether it matches a keyword. E.g., after FROM the next word is a table name.
fn is_strict_identifier_context(ctx: GrammarContext) -> boolContexts where the next word is always an identifier (a name), regardless of whether it matches a keyword. E.g., after FROM the next word is a table name.