async fn describe_schema(
session: &CqlSession,
writer: &mut dyn Write,
) -> Result<()>Expand description
DESCRIBE SCHEMA — show CREATE statements for all user keyspaces and their tables.
async fn describe_schema(
session: &CqlSession,
writer: &mut dyn Write,
) -> Result<()>DESCRIBE SCHEMA — show CREATE statements for all user keyspaces and their tables.