pub struct ProxyAddressTranslator {
proxy_address: SocketAddr,
}Expand description
An [AddressTranslator] that redirects all peer connections to the original
contact point address. Used when the cluster is accessed through a proxy.
All discovered node addresses are translated to proxy_address, ensuring
the driver only connects through the proxy endpoint.
Fields
proxy_address: SocketAddrThe proxy/contact point address to route all connections through.
Implementations
Sourceimpl ProxyAddressTranslator
impl ProxyAddressTranslator
Sourcepub fn new(proxy_address: SocketAddr) -> Self
pub fn new(proxy_address: SocketAddr) -> Self
Create a new translator that routes all connections to proxy_address.