ScyllaDriver

Struct ScyllaDriver 

pub struct ScyllaDriver {
    session: Session,
    prepared_cache: Mutex<HashMap<Vec<u8>, PreparedStatement>>,
    consistency: Mutex<Consistency>,
    serial_consistency: Mutex<Option<Consistency>>,
    tracing_enabled: AtomicBool,
    last_trace_id: Mutex<Option<Uuid>>,
}
ScyllaDriver wraps a scylla Session and provides the CqlDriver trait.

Fields

session: Sessionprepared_cache: Mutex<HashMap<Vec<u8>, PreparedStatement>>

Cache of prepared statements keyed by internal ID.

consistency: Mutex<Consistency>

Current consistency level.

serial_consistency: Mutex<Option<Consistency>>

Current serial consistency level.

tracing_enabled: AtomicBool

Whether tracing is enabled for queries.

last_trace_id: Mutex<Option<Uuid>>

Last tracing session ID.

Implementations

Source

impl ScyllaDriver

fn build_rustls_config(ssl_config: &SslConfig) -> Result<Arc<ClientConfig>>

Build the TLS configuration from SslConfig.

fn extract_string_list_val(val: Option<&CqlValue>) -> Vec<String>

Extract a Vec<String> from a CqlValue::List column value.

fn convert_query_result(result: QueryResult) -> Result<CqlResult>

Convert a scylla QueryResult into our CqlResult type.

fn convert_scylla_value(value: ScyllaCqlValue) -> CqlValue

Convert a scylla CqlValue to our CqlValue type.

fn internal_to_scylla_cql(v: &CqlValue) -> ScyllaCqlValue

Convert our internal CqlValue to scylla’s CqlValue (reverse of convert_scylla_value).

fn to_scylla_consistency(c: Consistency) -> Consistency

Convert our Consistency to scylla’s Consistency.

fn to_scylla_serial_consistency(c: Consistency) -> Option<SerialConsistency>

Convert our Consistency to scylla’s SerialConsistency.

fn build_query(&self, cql: &str) -> Statement

Build a Statement with the current consistency and tracing settings.

fn store_trace_id(&self, result: &QueryResult)

Store tracing ID from a result if present.