pub fn classify_error(error: &Error) -> ClassifiedErrorExpand description
Classify an anyhow error by walking the chain to find a DbError.
pub fn classify_error(error: &Error) -> ClassifiedErrorClassify an anyhow error by walking the chain to find a DbError.