run_cql_in_process

Function run_cql_in_process 

pub async fn run_cql_in_process(
    host: &str,
    port: u16,
    keyspace: Option<&str>,
    cql: &str,
) -> Result<String>
Execute a CQL string against a remote host and return the captured stdout output.

Connects to the given host/port, optionally uses keyspace, then runs cql as if it were passed to -e. This runs in-process so cargo tarpaulin can measure coverage for all code paths exercised.