page_stream

Function page_stream 

pub fn page_stream(title: &str) -> Result<PagerWriter>
Spawn a pager for streaming output, returning a PagerWriter to write rows into.

All pager variants receive data via piped stdin. less buffers received bytes in its own internal temp file, enabling full backward scrolling without holding all rows in our process memory. On drop, an end-of-results marker is written and we wait for the user to quit the pager.