pub struct CliArgs {Show 28 fields
pub host: Option<String>,
pub port: Option<u16>,
pub color: bool,
pub no_color: bool,
pub browser: Option<String>,
pub ssl: bool,
pub no_file_io: bool,
pub debug: bool,
pub coverage: bool,
pub execute: Option<String>,
pub file: Option<String>,
pub keyspace: Option<String>,
pub username: Option<String>,
pub password: Option<String>,
pub connect_timeout: Option<u64>,
pub request_timeout: Option<u64>,
pub tty: bool,
pub encoding: Option<String>,
pub cqlshrc: Option<String>,
pub cqlversion: Option<String>,
pub protocol_version: Option<u8>,
pub consistency_level: Option<String>,
pub serial_consistency_level: Option<String>,
pub no_compact: bool,
pub disable_history: bool,
pub secure_connect_bundle: Option<String>,
pub completions: Option<Shell>,
pub generate_man: bool,
}Expand description
The Apache Cassandra interactive CQL shell (Rust implementation).
Connects to a Cassandra cluster and provides an interactive shell for executing CQL statements.
Fields
host: Option<String>Contact point hostname (default: 127.0.0.1)
port: Option<u16>Native transport port (default: 9042)
color: boolForce colored output
no_color: boolDisable colored output
browser: Option<String>Browser for CQL HELP (unused in modern cqlsh)
ssl: boolEnable SSL/TLS connection
no_file_io: boolDisable file I/O commands (COPY, SOURCE, CAPTURE)
debug: boolShow additional debug info
coverage: boolCollect coverage (internal, accepted but ignored)
execute: Option<String>Execute a CQL statement and exit
file: Option<String>Execute statements from a file
keyspace: Option<String>Default keyspace
username: Option<String>Authentication username
password: Option<String>Authentication password
connect_timeout: Option<u64>Connection timeout in seconds
request_timeout: Option<u64>Per-request timeout in seconds
tty: boolForce TTY mode
encoding: Option<String>Set character encoding (default: utf-8)
cqlshrc: Option<String>Path to cqlshrc file (default: ~/.cassandra/cqlshrc)
cqlversion: Option<String>CQL version to use
protocol_version: Option<u8>Native protocol version
consistency_level: Option<String>Initial consistency level
serial_consistency_level: Option<String>Initial serial consistency level
no_compact: boolDisable compact storage interpretation
disable_history: boolDisable saving of command history
secure_connect_bundle: Option<String>Secure connect bundle for Astra DB
completions: Option<Shell>Generate shell completion script for the given shell (bash, zsh, fish, elvish, powershell)
generate_man: boolGenerate man page to stdout (hidden, used by release pipeline)
Implementations